referrerpolicy=no-referrer-when-downgrade

WorkState

Struct WorkState 

pub struct WorkState<N> {
    pub assignments: Vec<(CoreAssignment, AssignmentState)>,
    pub end_hint: Option<N>,
    pub pos: u16,
    pub step: PartsOf57600,
}

Fields

assignments: Vec<(CoreAssignment, AssignmentState)>

Assignments with current state.

Assignments and book keeping on how much has been served already. We keep track of serviced assignments in order to adhere to the specified ratios.

end_hint: Option<N>

When do our assignments become invalid if at all?

If this is Some, then this CoreState will be dropped at that block number. If this is None, then we will keep serving our core assignments in a circle until a new set of assignments is scheduled.

pos: u16

Position in the assignments we are currently in.

Aka which core assignment will be popped next on AssignmentProvider::advance_assignments.

step: PartsOf57600

Step width

How much we subtract from AssignmentState::remaining for a core served.